@@ -5,6 +5,7 @@
 #include "core/int_types.h"
 #include "core/mem.h"
 #include "core/platform.h"
+#include "core/pointer.h"
 #include "core/slice.h"
 #include "std/alloc.h"
 #include "std/audio.h"
@@ -16,6 +17,7 @@
 #include "std/gl.h"
 #include "std/gui.h"
 #include "std/image.h"
+#include "std/input/input.h"
 #include "std/input/key.h"
 #include "std/input/mouse.h"
 #include "std/input/touch.h"
